==> knights-trinity_3.5.13.2.orig.tar.xz: knights-trinity-3.5.13.2/knights/accel.h <==
/***************************************************************************
                          accel.h  -  description
                             -------------------
    begin                : Wed Nov 6 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ACCEL_H
#define ACCEL_H

#include <kaccel.h>

/**
  *@author Troy Corbin Jr.
  */

class Accel : public KAccel
{
	Q_OBJECT
  TQ_OBJECT

	public:
											Accel( TQWidget *parent=0, TQObject *target=0 );
											~Accel();
		void							setTarget( TQObject* );

	signals:
		void							focus( void );
		void							focus( const TQChar& );

		void							board_up( void );
		void							board_down( void );

		void							move_prev( void );
		void							move_next( void );

		void							page_up( void );
		void							page_down( void );

		void							history_prev( void );
		void							history_next( void );

		void							reply_tell( void );
		void							reply_channel( void );

		void							kibitz( void );
		void							whisper( void );
};

#endif

==> knights-trinity-14.0.8.tar.xz: knights-trinity-14.0.8/knights/accel.h <==
/***************************************************************************
                          accel.h  -  description
                             -------------------
    begin                : Wed Nov 6 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ACCEL_H
#define ACCEL_H

#include <tdeaccel.h>

/**
  *@author Troy Corbin Jr.
  */

class Accel : public TDEAccel
{
	Q_OBJECT
  

	public:
											Accel( TQWidget *parent=0, TQObject *target=0 );
											~Accel();
		void							setTarget( TQObject* );

	signals:
		void							focus( void );
		void							focus( const TQChar& );

		void							board_up( void );
		void							board_down( void );

		void							move_prev( void );
		void							move_next( void );

		void							page_up( void );
		void							page_down( void );

		void							history_prev( void );
		void							history_next( void );

		void							reply_tell( void );
		void							reply_channel( void );

		void							kibitz( void );
		void							whisper( void );
};

#endif
